@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.assets._jsii
 import aws_cdk.aws_certificatemanager._jsii
@@ -23,9 +23,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-apigateway",
-    "1.63.0",
+    "1.65.0",
     __name__[0:-6],
-    "aws-apigateway@1.63.0.jsii.tgz",
+    "aws-apigateway@1.65.0.jsii.tgz",
 )
 
 __all__ = [
